==> dxde_1.40.6-1.tar.gz: BUILD/src/gui/dialogs/firmadialog.h <==
/***************************************************************
 * Name:      firmadialog.h
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#ifndef FIRMADIALOG_H
#define FIRMADIALOG_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif
#include <wx/filepicker.h>
#include "model/dbmodel.h"

class FirmaDialog: public wxDialog
{
    DECLARE_DYNAMIC_CLASS(FirmaDialog)
    DECLARE_EVENT_TABLE()
public:
    FirmaDialog() : m_edit(false), m_mainSizer(nullptr), m_nazev(nullptr), m_ulice(nullptr), m_cp(nullptr), m_psc(nullptr),
    m_misto(nullptr), m_zeme(nullptr), m_ic(nullptr), m_dic(nullptr), m_registrace(nullptr), m_pausal(nullptr), m_platce(nullptr), m_eet(nullptr), m_telefon(nullptr),
    m_email(nullptr), m_www(nullptr), m_logo(nullptr), m_razitko(nullptr), m_logoSelect(nullptr), m_razitkoSelect(nullptr) {}
    FirmaDialog(wxWindow *parent, bool edit);
private:
    bool m_edit;
    wxBoxSizer *m_mainSizer;
    wxTextCtrl *m_nazev;
    wxTextCtrl *m_ulice;
    wxTextCtrl *m_cp;
    wxTextCtrl *m_psc;
    wxTextCtrl *m_misto;
    wxTextCtrl *m_zeme;
    wxTextCtrl *m_ic;
    wxTextCtrl *m_dic;
    wxTextCtrl *m_registrace;
    wxCheckBox *m_pausal;
    wxCheckBox *m_platce;
    wxCheckBox *m_eet;
    wxTextCtrl *m_telefon;
    wxTextCtrl *m_email;
    wxTextCtrl *m_www;
    wxTextCtrl *m_logo;
    wxTextCtrl *m_razitko;
    wxButton *m_logoSelect;
    wxButton *m_razitkoSelect;

    void createControls();
    void fillControls();
    void OnOk(wxCommandEvent& event);
    void OnCancel(wxCommandEvent& event);
    void OnLogo(wxCommandEvent& event);
    void OnRazitko(wxCommandEvent& event);
};

#endif  /* FIRMADIALOG_H */

==> dxde_1.40.12-1.tar.gz: BUILD/src/gui/dialogs/firmadialog.h <==
/***************************************************************
 * Name:      firmadialog.h
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#ifndef FIRMADIALOG_H
#define FIRMADIALOG_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif
#include <wx/filepicker.h>
#include "model/dbmodel.h"

class FirmaDialog: public wxDialog
{
    DECLARE_DYNAMIC_CLASS(FirmaDialog)
    DECLARE_EVENT_TABLE()
public:
    FirmaDialog() : m_edit(false), m_mainSizer(nullptr), m_nazev(nullptr), m_ulice(nullptr), m_cp(nullptr), m_psc(nullptr),
    m_misto(nullptr), m_zeme(nullptr), m_ic(nullptr), m_dic(nullptr), m_registrace(nullptr), m_pausal(nullptr), m_platce(nullptr), m_telefon(nullptr),
    m_email(nullptr), m_www(nullptr), m_logo(nullptr), m_razitko(nullptr), m_logoSelect(nullptr), m_razitkoSelect(nullptr) {}
    FirmaDialog(wxWindow *parent, bool edit);
private:
    bool m_edit;
    wxBoxSizer *m_mainSizer;
    wxTextCtrl *m_nazev;
    wxTextCtrl *m_ulice;
    wxTextCtrl *m_cp;
    wxTextCtrl *m_psc;
    wxTextCtrl *m_misto;
    wxTextCtrl *m_zeme;
    wxTextCtrl *m_ic;
    wxTextCtrl *m_dic;
    wxTextCtrl *m_registrace;
    wxCheckBox *m_pausal;
    wxCheckBox *m_platce;
    wxTextCtrl *m_telefon;
    wxTextCtrl *m_email;
    wxTextCtrl *m_www;
    wxTextCtrl *m_logo;
    wxTextCtrl *m_razitko;
    wxButton *m_logoSelect;
    wxButton *m_razitkoSelect;

    void createControls();
    void fillControls();
    void OnOk(wxCommandEvent& event);
    void OnCancel(wxCommandEvent& event);
    void OnLogo(wxCommandEvent& event);
    void OnRazitko(wxCommandEvent& event);
};

#endif  /* FIRMADIALOG_H */
